---
name: Bug report
about: Create a report to help us improve
title: ''
labels: 'kind: bug'
assignees: ''

---

<!-- Provide a concise summary of the issue in the title above. -->

#### What is the issue you have?

<!-- Provide a detailed introduction to the issue itself, and why you consider it to be a bug. -->
<!-- If possible, be specific and add stack traces, error messages, etc. Avoid vague terms like "crash" or "doesn't work". -->

#### Please describe the steps to reproduce the issue.

<!-- Provide a link to a live example, or an unambiguous set of steps to -->
<!-- reproduce this bug. Include code to reproduce, if relevant -->

1.
2.
3.

#### Can you provide a small but working code example?

<!-- Please understand that we cannot analyze and debug large code bases. -->

#### What is the expected behavior?

<!-- Tell us what should happen -->

#### And what is the actual behavior instead?

<!-- Tell us what happens instead. -->

#### Which compiler and operating system are you using?

<!-- Include as many relevant details about the environment you experienced the bug in. -->
<!-- Make sure you use a supported compiler, see https://github.com/nlohmann/json#supported-compilers. -->

- Compiler: ___
- Operating system: ___

#### Which version of the library did you use?

<!-- Please add an `x` to the respective line. -->

- [ ] latest release version 3.10.5
- [ ] other release - please state the version: ___
- [ ] the `develop` branch

#### If you experience a compilation error: can you [compile and run the unit tests](https://github.com/nlohmann/json#execute-unit-tests)?

- [ ] yes
- [ ] no - please copy/paste the error message below
